#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_INTERLEAVE_ODD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_INTERLEAVE_ODD_HPP_INCLUDED

#include <boost/simd/swar/include/functions/interleave_odd.hpp>

#endif
